import 'package:flutter/material.dart';
import '../clx_verification_code.dart';

class CLXLineCodeManageView extends StatelessWidget {
  const CLXLineCodeManageView({
    super.key,
    required this.loigc,
    required this.config,
    this.disabled = false,
  });

  /// 页面状态变化处理控制器
  final CLXCodeManageLogic loigc;

  /// 是否禁用
  final bool disabled;

  /// 样式配置
  final LineCodeManageConfig config;

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: config.margin,
      padding: config.padding,
      decoration: config.decoration,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Expanded(
                child: TextField(
                  controller: loigc.codeInoutCtrl,
                  keyboardType: TextInputType.number,
                  maxLength: loigc.maxLength,
                  style: config.style,
                  enabled: !disabled,
                  enableInteractiveSelection: false,
                  decoration: InputDecoration(
                    isCollapsed: config.isCollapsed,
                    counterText: '',
                    hintText: config.hintText,
                    hintStyle: config.hintStyle,
                    border: InputBorder.none,
                  ),
                ),
              ),
              const SizedBox(width: 10),
              Obx(
                () => Visibility(
                  visible: loigc.codeSendBtn.value.isNotEmpty,
                  child: GestureDetector(
                    onTap: loigc.sendSmsCode,
                    child: Text(
                      loigc.codeSendBtn.value,
                      style: loigc.codeSendType.value.isUnSend
                          ? config.countdownStyle
                          : config.codeSendStyle,
                    ),
                  ),
                ),
              ),
            ],
          ),
          Obx(
            () => Visibility(
              visible: loigc.verifyCodeError.value.isNotEmpty,
              child: Column(
                children: [
                  const SizedBox(height: 5),
                  Text(
                    loigc.verifyCodeError.value,
                    style: config.errorStyle,
                  ),
                ],
              ),
            ),
          ),
          Obx(
            () => Visibility(
              visible: loigc.isShowTip.value,
              child: Column(
                children: [
                  /// 展示重新发送验证码按钮以及获取语音验证码按钮
                  if (loigc.codeSendType.value ==
                      CodeSendType.notReceiveSmsCode)
                    NoReceiveSmsView(
                      isAccessOutCall: loigc.isAccessOutbound,
                      tipsStyle: config.tipsStyle,
                      reSendStyle: config.reSendStyle,
                      voiceSendStyle: config.voiceSendStyle,
                      isSmallWindow: config.isSmallWindow,
                      sendSmsCode: loigc.sendSmsCode,
                      sendVoiceCode: loigc.sendVoiceCode,
                    ),

                  /// 展示没有收到二次发送的验证码的提示
                  if (loigc.codeSendType.value ==
                      CodeSendType.notReceiveResendSmsCode)
                    NoReceiveResendSmsView(
                      isAccessOutCall: loigc.isAccessOutbound,
                      tipsStyle: config.tipsStyle,
                      reSendStyle: config.reSendStyle,
                      sendVoiceCode: loigc.sendVoiceCode,
                    ),

                  /// 展示没有收到首次发送的语音验证码的提示
                  if (loigc.codeSendType.value ==
                          CodeSendType.notReceiveVoiceCode ||
                      loigc.codeSendType.value ==
                          CodeSendType.notReceiveResendVoiceCode)
                    NoReceiveVoiceView(
                      isSmallWindow: config.isSmallWindow,
                      tipsStyle: config.tipsStyle,
                      reSendStyle: config.reSendStyle,
                      contactStyle: config.contactStyle,
                      sendVoiceCode: loigc.sendVoiceCode,
                      contactService: loigc.contactService,
                      isShowContact: loigc.codeSendType.value ==
                          CodeSendType.notReceiveResendVoiceCode,
                    ),
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }
}
